==> haskell-resource-pool-0.2.3.2-14-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-21N7ezGHoldXZQkL6dM1P
key: resource-pool-0.2.3.2-21N7ezGHoldXZQkL6dM1P
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
abi: e164c680a52a1eb4167b55a4c1e75298
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-21N7ezGHoldXZQkL6dM1P
depends:
    base-4.9.0.0 hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-resource-pool-0.2.3.2-15-i686.pkg.tar.xz: usr/share/haskell/register/haskell-resource-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: resource-pool
version: 0.2.3.2
id: resource-pool-0.2.3.2-IvrPp1JcX2T6Ac9cWpKKrl
key: resource-pool-0.2.3.2-IvrPp1JcX2T6Ac9cWpKKrl
license: BSD3
copyright: Copyright 2011 MailRank, Inc.
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>,
            Bas van Dijk <v.dijk.bas@gmail.com>
homepage: http://github.com/bos/pool
synopsis: A high-performance striped resource pooling implementation
description:
    A high-performance striped pooling abstraction for managing
    flexibly-sized collections of resources such as database
    connections.
category: Data, Database, Network
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules:
    Data.Pool
abi: 7f850bc8e7d7b875d2f27889c9fbb807
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/resource-pool-0.2.3.2
data-dir: /usr/share/i386-linux-ghc-8.0.1/resource-pool-0.2.3.2
hs-libraries: HSresource-pool-0.2.3.2-IvrPp1JcX2T6Ac9cWpKKrl
depends:
    base-4.9.0.0 hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    monad-control-1.0.2.0-4qPEnRApnc4gRDkIzJcM5
    stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg time-1.6.0.1
    transformers-0.5.2.0 transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-resource-pool/html/resource-pool.haddock
haddock-html: /usr/share/doc/haskell-resource-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
